@@ -3,6 +3,7 @@ from abc import ABC, abstractmethod
 from collections.abc import AsyncIterator, Callable, Iterable
 from contextlib import AbstractAsyncContextManager, asynccontextmanager, nullcontext
 from dataclasses import dataclass
+from functools import cache
 from os import environ
 from pathlib import Path
 from typing import Any, Literal, Optional, cast
@@ -37,6 +38,8 @@ class Linux(OS):
         for line in release_file.splitlines():
             k, v = line.split("=", 1)
             if k == "ID":
+                if v.startswith('"') and v.endswith('"'):
+                    v = v[1:-1]
                 return v
 
         raise ValueError(f"Cannot find distribution ID in {cls.RELEASE_FILE}.")
@@ -70,6 +73,7 @@ class Driver(ABC):
     def deconstruct(self) -> dict:
         return {"root": self.root}
 
+    @cache
     def with_root(self, /, root: bool) -> "Driver":
         if self.root == root:
             return self
@@ -149,10 +153,9 @@ class Driver(ABC):
         *,
         name: Some[str] = None,
         file_type: Some[str] = None,
-        mindepth: Optional[int] = None,
         maxdepth: Optional[int] = None,
     ) -> list[Path]:
-        args: list[RunArg] = ["find", path]
+        args: list[RunArg] = ["find", path, "-mindepth", "1"]
 
         def add_some_arg(arg: str, values: list[str]) -> None:
             if values:
@@ -166,7 +169,6 @@ class Driver(ABC):
             if value is not None:
                 args.extend([arg, str(value)])
 
-        add_optional_arg("-mindepth", mindepth)
         add_optional_arg("-maxdepth", maxdepth)
         add_some_arg("-name", unsome(name))
         add_some_arg("-type", unsome(file_type))
@@ -239,8 +241,7 @@ class Driver(ABC):
         if result == "x86_64":
             return "x86_64"
         elif result in {"arm64", "aarch64"}:
-            # No ARM runners on CI
-            return "aarch64"  # pragma: no cover
+            return "aarch64"
         else:
             raise ValueError(f"Unsupported architecture {result}.")  # pragma: no cover
 
