@@ -19,7 +19,7 @@ class Extractor(ABC):
             stripped = 0
 
             while True:
-                contents = await self.driver.find(source_dir, mindepth=1, maxdepth=1)
+                contents = await self.driver.find(source_dir, maxdepth=1)
                 if len(contents) != 1:
                     # Multiple files/directories on this level
                     break
@@ -36,7 +36,7 @@ class Extractor(ABC):
                         f"Too many nested directories after extracting, got {source_dir}."
                     )
 
-            for element in await self.driver.find(source_dir, mindepth=1, maxdepth=1):
+            for element in contents:
                 await self.driver.copy(element, target_directory / element.name)
 
     @abstractmethod
@@ -92,6 +92,7 @@ async def get_redirect_url(url: str, *, driver: Driver) -> str:
         "%{url_effective}",
         "--head",
         "--no-include",
+        "--fail",
         "--silent",
         "--show-error",
         "--location",
@@ -116,12 +117,16 @@ class RawExtractor(ABC):
         pass
 
 
-class Gzip(RawExtractor):
+class ShellRedirectRawExtractor(RawExtractor):
+    def __init__(self, *, driver: Driver, command: str):
+        super().__init__(driver=driver)
+        self.command = command
+
     async def extract(self, *, archive: Path, target: Path) -> None:
         await self.driver.run(
             "sh",
             "-c",
-            f"gunzip < {shlex.quote(str(archive))} > {shlex.quote(str(target))}",
+            f"{self.command} < {shlex.quote(str(archive))} > {shlex.quote(str(target))}",
         )
 
 
@@ -132,7 +137,11 @@ class Move(RawExtractor):
 
 def _guess_single_extractor(url: str, *, driver: Driver) -> RawExtractor:
     if url.endswith(".gz"):
-        return Gzip(driver=driver)
+        return ShellRedirectRawExtractor(driver=driver, command="gunzip")
+    elif url.endswith(".xz"):
+        return ShellRedirectRawExtractor(driver=driver, command="xzcat")
+    elif url.endswith(".bz2"):
+        return ShellRedirectRawExtractor(driver=driver, command="bunzip2")
     else:
         raise ValueError(f"Unknown archive format: {url}")
 
