@@ -1,36 +1,33 @@
-import argparse
 import sys
 from pathlib import Path
-from typing import Optional
+from typing import cast
 
 import trio
-from typed_argparse import TypedArgs
+import typed_argparse as tap
 
 from .driver import LocalDriver
 from .manager import Manager
 from .state import DB, DB_PATH
 
 
-class Args(TypedArgs):
-    component: list[str]
+class Args(tap.TypedArgs):
+    pass
 
 
-def parse_args(args: Optional[list[str]] = None) -> Args:
-    result = argparse.ArgumentParser(description="Install the environment")
-    result.add_argument("component", nargs="*", help="The component to install")
-    return Args.from_argparse(result.parse_args(args))
+def parse_args() -> Args:
+    return cast(
+        Args, tap.Parser(Args, description="Install the environment").parse_args()
+    )
 
 
 async def main() -> int:
-    args = parse_args()
+    parse_args()
 
     db = DB(DB_PATH)
     driver = LocalDriver()
-    manager = Manager(db=db, driver=driver, component_path=Path("packages"))
+    manager = Manager(db=db, driver=driver, data_path=Path())
 
-    components: frozenset[str] = frozenset(args.component) | {"base"}
-
-    result = await manager.install(components)
+    result = await manager.install()
 
     if result.installed:
         print(
