@@ -1,14 +1,16 @@
 from collections.abc import AsyncIterable, Iterable, Sequence
 from dataclasses import dataclass
 from pathlib import Path
+from typing import Any
 
 import yaml
 
+from .config import MatchConfig, parse_config
 from .driver import Driver
 from .package import Package, parse_packages
-from .parallel import PartialException, PartialResults, parallel_map_tqdm
+from .parallel import PartialException, PartialResults, parallel_map_progress
 from .state import DB, VERSIONS
-from .tracker import ManagerTracker, Tracker
+from .tracker import ManagerTracker, tracking
 from .utils import flatten
 
 
@@ -17,17 +19,28 @@ class InstallResult:
     installed: list[Package]
     failed: list[tuple[Package, BaseException]]
 
+    def raise_for_failures(self) -> None:  # pragma: no cover
+        if self.failed:
+            for _, exc in self.failed:
+                raise exc
+
 
 @dataclass
 class Manager:
     db: DB
     driver: Driver
-    component_path: Path
+    data_path: Path
+
+    def load_data(self, *path: str) -> Any:
+        with open(self.data_path / Path(*path)) as f:
+            return yaml.safe_load(f)
+
+    def load_config(self) -> list[MatchConfig]:
+        return parse_config(self.load_data("mybox.yaml"), driver=self.driver)
 
     def load_component(self, component: str) -> Sequence[Package]:
-        with open(self.component_path / f"{component}.yaml") as f:
-            packages = yaml.safe_load(f)
-            return parse_packages(packages, db=self.db, driver=self.driver)
+        packages = self.load_data("packages", f"{component}.yaml")
+        return parse_packages(packages, db=self.db, driver=self.driver)
 
     def load_components(self, components: frozenset[str]) -> list[Package]:
         return flatten(self.load_component(component) for component in components)
@@ -43,19 +56,21 @@ class Manager:
             if package not in package_names:
                 versions.delete(id=package)
 
-    async def install(self, components: frozenset[str]) -> InstallResult:
-        packages = self.load_components(components)
+    async def install(self) -> InstallResult:
+        config = self.load_config()
+        components = await MatchConfig.components(config)
+        packages = self.load_components(frozenset(components))
 
         return await self.install_packages(packages)
 
     async def install_packages(self, packages: list[Package]) -> InstallResult:
-        async with Tracker.tracking(driver=self.driver, db=self.db) as tracker:
+        async with tracking(driver=self.driver, db=self.db) as tracker:
 
             async def process_and_record(package: Package) -> Iterable[Package]:
                 return [pkg async for pkg in self.install_package(tracker, package)]
 
             try:
-                results = await parallel_map_tqdm(process_and_record, packages)
+                results = await parallel_map_progress(process_and_record, packages)
 
                 await self.cleanup(packages)
 
@@ -87,7 +102,7 @@ class Manager:
                 tracker.skip(package.name)
                 return
 
-            await package.install(tracker=tracker.track(package.name))
+            await package.install(tracker=tracker.for_package(package.name))
         except:
             tracker.skip(package.name)
             raise
