@@ -1,15 +1,25 @@
 from abc import ABC, abstractmethod
 from collections.abc import AsyncIterable
 from functools import cached_property
+from pathlib import Path
 from typing import Optional
 
-from pydantic import BaseModel, ConfigDict, Field
+from pydantic import AliasChoices, AliasPath, BaseModel, ConfigDict, Field
 
 from ..driver import Driver
 from ..parallel import gather_
 from ..state import DB
 from ..tracker import Tracker
-from ..utils import allow_singular, async_cached, matches_if_specified
+from ..utils import (
+    allow_singular,
+    allow_singular_none,
+    async_cached,
+    matches_if_specified,
+)
+
+PackageArgs = dict[
+    str, str | bool | int | Path | list[str] | dict[str, str | list[str]]
+]
 
 
 class Package(BaseModel, ABC):
@@ -26,17 +36,22 @@ class Package(BaseModel, ABC):
 
     name_: Optional[str] = Field(default=None, alias="name")
 
-    os: Optional[list[str]] = None
+    os: Optional[list[str]] = Field(
+        default=None, validation_alias=AliasChoices(AliasPath("$if", "os"), "os")
+    )
     os_val = allow_singular("os")
 
     distribution: Optional[list[str]] = None
     distribution_val = allow_singular("distribution")
 
+    root: bool = False
+
+    post: list[str] = Field(default_factory=list)
+    post_val = allow_singular_none("post")
+
     db: DB
     driver_: Driver = Field(..., alias="driver")
 
-    root: bool = False
-
     @property
     def driver(self) -> Driver:
         return self.driver_.with_root(self.root)
@@ -66,12 +81,16 @@ class Package(BaseModel, ABC):
 
     @abstractmethod
     async def install(self, *, tracker: Tracker) -> None:
-        pass
+        for cmd in self.post:
+            await self.driver.run("sh", "-c", cmd)
 
     async def applicable(self) -> bool:
         os = await self.driver.os()
         return os.switch_(
-            linux=lambda linux: matches_if_specified(self.os, "linux")
+            linux=lambda linux: (
+                matches_if_specified(self.os, "linux")
+                or matches_if_specified(self.os, linux.distribution)
+            )
             and matches_if_specified(self.distribution, linux.distribution),
             macos=lambda: matches_if_specified(self.os, "darwin"),
         )
