@@ -5,6 +5,7 @@ from dataclasses import dataclass
 from subprocess import CalledProcessError
 from typing import Any, Optional
 
+import httpx
 from pydantic import Field
 
 from ..driver import OS, Architecture
@@ -23,12 +24,12 @@ from .archive import ArchivePackage
 async def github_auth_token() -> Optional[str]:
     try:
         return os.environ["GITHUB_TOKEN"]
-    except KeyError:
+    except KeyError:  # pragma: no cover
         pass
 
-    try:
+    try:  # pragma: no cover
         return await run_output("gh", "auth", "token", silent=True)
-    except (CalledProcessError, FileNotFoundError):
+    except (CalledProcessError, FileNotFoundError):  # pragma: no cover
         pass
 
     return None  # pragma: no cover
@@ -56,10 +57,23 @@ class GitHubReleaseArtifact:
 class GitHubRelease:
     id: int
     tag_name: str
-    draft: bool
     prerelease: bool
     assets: list[GitHubReleaseArtifact]
 
+    @classmethod
+    def from_json(cls, data: dict[str, Any]) -> "GitHubRelease":
+        return cls(
+            id=data["id"],
+            tag_name=data["tag_name"],
+            prerelease=data["prerelease"],
+            assets=[
+                GitHubReleaseArtifact(
+                    name=result["name"], url=result["browser_download_url"]
+                )
+                for result in data["assets"]
+            ],
+        )
+
 
 ARCHITECTURE_FILTERS: dict[str, list[str]] = {
     "aarch64": ["arm64", "arm"],
@@ -85,31 +99,33 @@ class GitHubPackage(ArchivePackage, Filters):
     @async_cached
     async def releases(self) -> list[GitHubRelease]:
         result = await github_api(f"repos/{self.repo}/releases")
-        return [
-            GitHubRelease(
-                id=release["id"],
-                tag_name=release["tag_name"],
-                draft=release["draft"],
-                prerelease=release["prerelease"],
-                assets=[
-                    GitHubReleaseArtifact(
-                        name=result["name"], url=result["browser_download_url"]
-                    )
-                    for result in release["assets"]
-                ],
-            )
-            for release in result
-        ]
+        return [GitHubRelease.from_json(release) for release in result]
+
+    @async_cached
+    async def latest_release(self) -> Optional[GitHubRelease]:
+        try:
+            result = await github_api(f"repos/{self.repo}/releases/latest")
+        except httpx.HTTPStatusError as e:
+            if e.response.status_code == 404:
+                return None
+            raise  # pragma: no cover
+        return GitHubRelease.from_json(result)
+
+    def want_release(self, release: GitHubRelease) -> bool:
+        if release.prerelease:
+            return False
+        if release.tag_name in self.skip_releases:
+            return False
+        return True
 
     async def release(self) -> GitHubRelease:
+        latest = await self.latest_release()
+        if latest and self.want_release(latest):
+            return latest
+
         candidates = await self.releases()
         for candidate in candidates:
-            if candidate.draft:
-                # Can't find any stably draft releases to test with
-                continue  # pragma: no cover
-            if candidate.prerelease:
-                continue
-            if candidate.tag_name in self.skip_releases:
+            if not self.want_release(candidate):
                 continue
             return candidate
         raise ValueError(f"No releases found for {self.repo}.")
@@ -121,7 +137,7 @@ class GitHubPackage(ArchivePackage, Filters):
         for signature_hint in [".asc", ".sig", "sha256", "sha512", ".yml"]:
             yield cls.excludes_(signature_hint)
 
-        for system_package_hint in [".deb", ".rpm", ".dmg", ".exe"]:
+        for system_package_hint in [".deb", ".rpm", ".dmg", ".exe", ".appimage"]:
             yield cls.excludes_(system_package_hint)
 
         yield from cls.from_synonyms(
@@ -132,7 +148,7 @@ class GitHubPackage(ArchivePackage, Filters):
 
         if target_os.switch(linux=True, macos=False):
             yield cls.includes_("gnu")
-            yield cls.excludes_("musl")
+            yield cls.excludes_("musl")  # pragma: no cover
 
     def all_filters(
         self, *, target_os: OS, target_arch: Architecture
