@@ -1,6 +1,7 @@
 import dataclasses
-from abc import ABCMeta, abstractmethod
-from typing import TYPE_CHECKING, Any, Callable, Generic, Iterable, Type, TypeVar
+from abc import ABC, abstractmethod
+from collections.abc import Callable, Iterable
+from typing import TYPE_CHECKING, Any, Generic, Type, TypeVar
 from uuid import uuid4
 
 from .db import DB
@@ -13,7 +14,7 @@ else:
     M = TypeVar("M")
 
 
-class Storage(Generic[M], metaclass=ABCMeta):
+class Storage(Generic[M], ABC):
     @abstractmethod
     def __getitem__(self, key: str) -> M:
         pass
